@@ -38,8 +38,12 @@ def makes(ivar2):
     
     print(f"[!] The process was completed. You can now remove the make() function from {__name__}.py")
 
-def run():
-    if os.path.exists(ivar):
-        print("[PYOS-MANAGER] Running OS as vewn...")
+def run(osfolder=None):
+    if osfolder is not None:
+        print("[PYOS-MANAGER] Running OS with PyOS.core.modules.oracle")
         time.sleep(1)
-    else: print(f"[PYOS-MANAGER] OS folder has not been identified. Identified as: {ivar}"); i = input('[!] Run folder? '); ivar = i; makes(ivar); 
\ No newline at end of file
+        try:
+            os.system(f'python3 {osfolder}/run.py')
+        except Exception:
+            print("[PYOS-MANAGER] Failed to run the OS with oracle: CODE 400")
+    else: print(f"[PYOS-MANAGER] OS folder has not been identified. Identified as: unknown"); i = input('[!] Run folder? '); ivar = i; makes(ivar); 
\ No newline at end of file
